==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/af.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Hoëkontrastema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "’n Hoëkontrastema om u navigasie te vergemaklik. Visuele kwaliteit sal verminder word, maar die duidelikheid sal verbeter.",
    "Dark theme (beta)" : "Donkertema (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "’n Donkertema om u oë ’n ruskans te geen deur die algehele ligsterkte en helderheid te verminder. Dit word nog ontwikkel; rapporteer asb. enige probleme wat u ervaar.",
    "Dyslexia font" : "Disleksie-font",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is ’n gratis lettertipe/font wat ontwerp is om sommige van die algemene leesfoute wat deur disleksie veroorsaak word, te versag.",
    "Accessibility" : "Toeganklikheid",
    "Accessibility options for nextcloud" : "Toeganklikheidsopsies vir nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Bied veelvuldige toeganklikheidsopsies om u gebruik van Nextcloud te vergemaklik",
    "Web Content Accessibility Guidelines" : "Webinhoudtoeganklikheidsriglyne",
    "our issue tracker" : "ons probleemnaspoorder",
    "our design team" : "ons ontwerpspan",
    "Enable" : "Aktiveer"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/af.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Hoëkontrastema",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "’n Hoëkontrastema om u navigasie te vergemaklik. Visuele kwaliteit sal verminder word, maar die duidelikheid sal verbeter.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "’n Donkertema om u oë ’n ruskans te geen deur die algehele ligsterkte en helderheid te verminder. Dit word nog ontwikkel; rapporteer asb. enige probleme wat u ervaar.",
    "Dyslexia font" : "Disleksie-font",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is ’n gratis lettertipe/font wat ontwerp is om sommige van die algemene leesfoute wat deur disleksie veroorsaak word, te versag.",
    "Accessibility" : "Toeganklikheid",
    "Accessibility options for nextcloud" : "Toeganklikheidsopsies vir nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Bied veelvuldige toeganklikheidsopsies om u gebruik van Nextcloud te vergemaklik",
    "Web Content Accessibility Guidelines" : "Webinhoudtoeganklikheidsriglyne",
    "our issue tracker" : "ons probleemnaspoorder",
    "our design team" : "ons ontwerpspan",
    "Enable" : "Aktiveer",
    "Dark theme (beta)" : "Donkertema (beta)"
},
"nplurals=2; plural=(n != 1);");
